@@ -1,6 +1,6 @@
 #  MIT License
 #
-#  Copyright (c) 2017-2022 TileDB Inc.
+#  Copyright (c) 2017-2024 TileDB Inc.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -33,8 +33,9 @@
 #'
 #' @export
 tiledb_object_type <- function(uri, ctx = tiledb_get_context()) {
-    stopifnot(`The 'ctx' argument must a tiledb_ctx` = is(ctx, "tiledb_ctx"),
-              `The 'uri' argument must be a string scalar` = !missing(uri) && is.scalar(uri,"character"))
+    stopifnot("The 'ctx' argument must a tiledb_ctx" = is(ctx, "tiledb_ctx"),
+              "The 'uri' argument must be a string scalar" =
+                  !missing(uri) && is.scalar(uri,"character"))
     libtiledb_object_type(ctx@ptr, uri)
 }
 
@@ -47,8 +48,9 @@ tiledb_object_type <- function(uri, ctx = tiledb_get_context()) {
 #' @return uri of removed TileDB resource
 #' @export
 tiledb_object_rm <- function(uri, ctx = tiledb_get_context()) {
-    stopifnot(`The 'ctx' argument must a tiledb_ctx` = is(ctx, "tiledb_ctx"),
-              `The 'uri' argument must be a string scalar` = !missing(uri) && is.scalar(uri,"character"))
+    stopifnot("The 'ctx' argument must a tiledb_ctx" = is(ctx, "tiledb_ctx"),
+              "The 'uri' argument must be a string scalar" =
+                  !missing(uri) && is.scalar(uri,"character"))
     libtiledb_object_remove(ctx@ptr, uri)
 }
 
@@ -62,9 +64,9 @@ tiledb_object_rm <- function(uri, ctx = tiledb_get_context()) {
 #' @return new uri of moved tiledb resource
 #' @export
 tiledb_object_mv <- function(old_uri, new_uri, ctx = tiledb_get_context()) {
-    stopifnot(`The 'ctx' argument must a tiledb_ctx` = is(ctx, "tiledb_ctx"),
-              `The 'old_uri' argument must be a string scalar` = !missing(old_uri) && is.scalar(old_uri,"character"),
-              `The 'new_uri' argument must be a string scalar` = !missing(new_uri) && is.scalar(new_uri,"character"))
+    stopifnot("The 'ctx' argument must a tiledb_ctx" = is(ctx, "tiledb_ctx"),
+              "The 'old_uri' argument must be a string scalar" = !missing(old_uri) && is.scalar(old_uri,"character"),
+              "The 'new_uri' argument must be a string scalar" = !missing(new_uri) && is.scalar(new_uri,"character"))
     libtiledb_object_move(ctx@ptr, old_uri, new_uri)
 }
 
@@ -76,20 +78,24 @@ tiledb_object_mv <- function(old_uri, new_uri, ctx = tiledb_get_context()) {
 #' @return a dataframe with object type, object uri string columns
 #' @export
 tiledb_object_ls <- function(uri, filter = NULL, ctx = tiledb_get_context()) {
-    stopifnot(`The 'ctx' argument must a tiledb_ctx` = is(ctx, "tiledb_ctx"),
-              `The 'uri' argument must be a string scalar` = !missing(uri) && is.scalar(uri,"character"))
+    stopifnot("The 'ctx' argument must a tiledb_ctx" = is(ctx, "tiledb_ctx"),
+              "The 'uri' argument must be a string scalar" =
+                  !missing(uri) && is.scalar(uri,"character"))
     libtiledb_object_walk(ctx@ptr, uri, order = "PREORDER")
 }
 
 #' Recursively discover TileDB resources at a given root URI path
 #'
 #' @param uri root uri path to walk
-#' @param order (default "PREORDER") specify "POSTORDER" for "POSTORDER" traversal
+#' @param order traversal order, one of "PREORDER" and "POSTORDER" (default "PREORDER")
 #' @param ctx tiledb_ctx object (optional)
 #' @return a dataframe with object type, object uri string columns
 #' @export
-tiledb_object_walk <- function(uri, order = "PREORDER", ctx = tiledb_get_context()) {
-    stopifnot(`The 'ctx' argument must a tiledb_ctx` = is(ctx, "tiledb_ctx"),
-              `The 'uri' argument must be a string scalar` = !missing(uri) && is.scalar(uri,"character"))
+tiledb_object_walk <- function(uri, order = c("PREORDER", "POSTORDER"), ctx = tiledb_get_context()) {
+    order <- match.arg(order)
+    stopifnot("The 'ctx' argument must a tiledb_ctx" = is(ctx, "tiledb_ctx"),
+              "The 'order' argument must be a string scalar" = is.scalar(order,"character"),
+              "The 'uri' argument must be a string scalar" =
+                  !missing(uri) && is.scalar(uri,"character"))
     libtiledb_object_walk(ctx@ptr, uri, order = order, recursive = TRUE)
 }
