@@ -47,7 +47,7 @@ read_array <- function(uri) {
 }
 
 read_as_df <- function(uri) {
-  A <- tiledb_array(uri = uri, as.data.frame = TRUE)
+  A <- tiledb_array(uri = uri, return_as = "data.frame")
   data <- A[3:7, 2:4]
   show(data)
 }
@@ -77,7 +77,7 @@ open_read_change_read <- function(uri) {
 }
 
 simple_ex <- function(uri) {
-  arr <- tiledb_array(uri, as.data.frame = TRUE)
+  arr <- tiledb_array(uri, return_as = "data.frame")
   show(arr[7:9, 2:3])
 }
 
