@@ -1,14 +1,14 @@
 library(tinytest)
 library(tiledb)
 
-isOldWindows <- Sys.info()[["sysname"]] == "Windows" && grepl('Windows Server 2008', osVersion)
-if (isOldWindows) exit_file("skip this file on old Windows releases")
+if (Sys.getenv("CI", "") == "") exit_file("Skip unextended test run")
 
 ctx <- tiledb_ctx(limitTileDBCores())
 
 if (!requireNamespace("arrow", quietly=TRUE)) exit_file("No 'arrow' package.")
 suppressMessages(library(arrow))
 
+
 if (get_return_as_preference() != "asis") set_return_as_preference("asis") 		# baseline value
 
 ## -- RecordBatch test (and TileDB does not yet export to / import from these)
